# eric7.QScintilla.Exporters.ExporterHTML

Module implementing an exporter for HTML.

### Global Attributes

None

### Classes

ExporterHTML | Class implementing an exporter for HTML.
HTMLGenerator | Class implementing an HTML generator for exporting source code.

### Functions

None

## ExporterHTML

Class implementing an exporter for HTML.

### Derived from

ExporterBase

### Class Attributes

None

### Class Methods

None

### Methods

ExporterHTML | Constructor
__generateFromMarkdown | Private method to convert Markdown text into HTML.
__generateFromReSTDocutils | Private method to convert ReST text into HTML using 'docutils'.
exportSource | Public method performing the export.

### Static Methods

None

#### ExporterHTML (Constructor)

ExporterHTML(editor, parent=None)

Constructor

editor
  reference to the editor object (QScintilla.Editor.Editor)
parent
  parent object of the exporter (QObject)

#### ExporterHTML.__generateFromMarkdown

__generateFromMarkdown(useDarkScheme)

Private method to convert Markdown text into HTML.

useDarkScheme (bool)
  flag indicating to export using a dark color scheme

Return:
  processed HTML

Return Type:
  str

#### ExporterHTML.__generateFromReSTDocutils

__generateFromReSTDocutils()

Private method to convert ReST text into HTML using 'docutils'.

Return:
  processed HTML (string)

#### ExporterHTML.exportSource

exportSource()

Public method performing the export.

Up

## HTMLGenerator

Class implementing an HTML generator for exporting source code.

### Derived from

None

### Class Attributes

None

### Class Methods

None

### Methods

HTMLGenerator | Constructor
generate | Public method to generate HTML for the source editor.

### Static Methods

None

#### HTMLGenerator (Constructor)

HTMLGenerator(editor)

Constructor

editor
  reference to the editor object (QScintilla.Editor.Editor)

#### HTMLGenerator.generate

generate(tabSize=4, useTabs=False, wysiwyg=True, folding=False, onlyStylesUsed=False, titleFullPath=False)

Public method to generate HTML for the source editor.

tabSize
  size of tabs (integer)
useTabs
  flag indicating the use of tab characters (boolean)
wysiwyg
  flag indicating colorization (boolean)
folding
  flag indicating usage of fold markers
onlyStylesUsed
  flag indicating to include only style definitions for styles used in the source (boolean)
titleFullPath
  flag indicating to include the full file path in the title tag (boolean)

Return:
  generated HTML text (string)

Up